@@ -533,8 +533,9 @@ EOF
 	my $warning;
 	local $SIG{__WARN__} = sub { $warning = $_[0] };
 	eval 'my $v = $CLASS->$method(~0);';
-	unlike($@, qr/Integer overflow in version/, "Too large version");
-	like($warning, qr/Integer overflow in version/, "Too large version");
+	unlike($@, qr/Integer overflow in version/, "Too large version: $@");
+	like($warning, qr/Integer overflow in version/, "Too large version:
+	    $warning");
     }
 
     {
